package INV_SINERCOM.AccesoDatos;

import java.io.IOException;
import java.sql.*;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.Date;
import net.sf.jasperreports.engine.*;
import net.sf.jasperreports.engine.util.JRLoader;
import net.sf.jasperreports.view.JasperViewer;

/// <summary>
/// Aplicación: INV_SINERCOM (INVENTARIO SINERCOM)
/// Módulo: PEDIDOS
/// Fecha:2014/09/30 
/// Empresa:SINERCOM
/// HISTORIA DE CAMBIOS
/// ----------------------------------------------------------------------
/// FECHA         USUARIO     DESCRIPCION
/// 2014/09/30    DRPAREDA    Creacion de Clase para manejo de Productos
/// ----------------------------------------------------------------------
/// </summary> 
public class ADInventario {

    private static ResultSet resultado = null;

    //Carga tipos de filtros de Pedidos disponibles en a base de datos
    public static ArrayList CargaTipoProductos(int CodigoCatalogo) {
        ArrayList valorRetorno = new ArrayList();
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_CONSULTA_CATALOGO_PARAMETRIZACION(?)}");
            proc.setInt(1, CodigoCatalogo);
            proc.execute();
            resultado = proc.getResultSet();
            while (resultado.next()) {
                valorRetorno.add(resultado.getString("nombre_detalle"));
            }
            ADConexionMySQL.Desconectar();
        } catch (SQLException e) {
        }

        return valorRetorno;
    }

    //Registra Nuevo producto al Inventario
    public static int IngresaInventario(int operacion, String codigoProducto, String descripcion, String marca, float valor, int tipoproducto, int cantidad) {
        int valorRetorno = 1;
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_REGISTRA_INVENTARIO(?,?,?,?,?,?,?)}");
            proc.setInt(1, operacion);
            proc.setString(2, codigoProducto);
            proc.setString(3, descripcion);
            proc.setString(4, marca);
            proc.setFloat(5, valor);
            proc.setInt(6, tipoproducto);
            proc.setInt(7, cantidad);
            proc.execute();
            resultado = proc.getResultSet();
            while (resultado.next()) {
                valorRetorno = resultado.getInt(1);
            }
            ADConexionMySQL.Desconectar();
        } catch (SQLException e) {
        }

        return valorRetorno;
    }

    //Carga tipos de filtros de Pedidos disponibles en a base de datos
    public static ResultSet CargaTipoPaquetes(int CodigoCatalogo) {
        resultado = null;
        ResultSet valorRetorno = null;
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_CONSULTA_PAQUETES_INVENTARIO(?)}");
            proc.setInt(1, CodigoCatalogo);
            proc.execute();
            resultado = proc.getResultSet();
            while (resultado.next()) {
                valorRetorno = resultado;
                return valorRetorno;
            }
            ADConexionMySQL.Desconectar();
        } catch (SQLException e) {
        }

        return valorRetorno;
    }

    //Registra Nuevo producto al Inventario
    public static int AsignaPaquetesInventario(String codigoProducto, int PaqueteProducto) {
        int valorRetorno = 1;
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_ASIGNA_PAQUETES_INVENTARIO(?,?)}");
            proc.setString(1, codigoProducto);
            proc.setInt(2, PaqueteProducto);
            proc.execute();
            resultado = proc.getResultSet();
            while (resultado.next()) {
                valorRetorno = resultado.getInt(1);
            }
            ADConexionMySQL.Desconectar();
        } catch (SQLException e) {
        }

        return valorRetorno;
    }

    //Carga lista de productos em base de datos del inventario
    public static ResultSet CargaInventarioIngreso(int operacion, int tipoProducto, String parametroBusqueda) throws SQLException {
        resultado = null;
        ResultSet valorRetorno = null;
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_CONSULTA_INVENTARIO(?,?,?)}");
            proc.setInt(1, operacion);
            proc.setInt(2, tipoProducto);
            proc.setString(3, parametroBusqueda);
            proc.execute();
            resultado = proc.getResultSet();
            while (resultado.next()) {
                valorRetorno = resultado;
                return valorRetorno;
            }
        } catch (SQLException e) {
        }
        return valorRetorno;
    }

    //Carga tipos de filtros de Pedidos disponibles en a base de datos
    public static ArrayList CargaTipoFiltrosInventario(int CodigoCatalogo) {
        ArrayList valorRetorno = new ArrayList();
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_CONSULTA_CATALOGO_PARAMETRIZACION(?)}");
            proc.setInt(1, CodigoCatalogo);
            proc.execute();
            resultado = proc.getResultSet();
            while (resultado.next()) {
                valorRetorno.add(resultado.getString("nombre_detalle"));
            }
            ADConexionMySQL.Desconectar();
        } catch (SQLException e) {
        }

        return valorRetorno;
    }

    //Carga lista de productos em base de datos del inventario
    public static ResultSet CargaInventarioConsulta(int operacion, int tipoProducto, String parametroBusqueda) throws SQLException {
        resultado = null;
        ResultSet valorRetorno = null;
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_CONSULTA_INVENTARIO_EDIT(?,?,?)}");
            proc.setInt(1, operacion);
            proc.setInt(2, tipoProducto);
            proc.setString(3, parametroBusqueda);
            proc.execute();
            resultado = proc.getResultSet();
            while (resultado.next()) {
                valorRetorno = resultado;
                return valorRetorno;
            }
        } catch (SQLException e) {
        }
        return valorRetorno;
    }

    //Edita el inventario
    public static int EditaInventario(String codigoProductoA, String codigoProductoN, String detalleProducto, int claseProducto, int tipoProducto,float valorUnitario) {
        int valorRetorno = 1;
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_EDITA_INVENTARIO(?,?,?,?,?,?)}");
            proc.setString(1, codigoProductoA);
            proc.setString(2, codigoProductoN);
            proc.setString(3, detalleProducto);
            proc.setInt(4, claseProducto);
            proc.setInt(5, tipoProducto);
            proc.setFloat(6, valorUnitario);

            proc.execute();
            resultado = proc.getResultSet();
            while (resultado.next()) {
                valorRetorno = resultado.getInt(1);
            }
            ADConexionMySQL.Desconectar();
        } catch (SQLException e) {
        }

        return valorRetorno;
    }
    
            //Carga lista de productos em base de datos base de datos
    public static ResultSet CargarReporteInventario(int operacion, int estadoInventario, String fechaInicio, String fechaFin) throws SQLException {
        resultado = null;
        ResultSet valorRetorno = null;
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_GENERA_REPORTE_INVENTARIO(?,?,?,?)}");
            proc.setInt(1, operacion);
            proc.setInt(2, estadoInventario);
            proc.setString(3, fechaInicio);
            proc.setString(4, fechaFin);
            proc.execute();
            resultado = proc.getResultSet();
            while (resultado.next()) {
                valorRetorno = resultado;
                return valorRetorno;
            }
        } catch (SQLException e) {
        }
        return valorRetorno;
    }
    
                //Carga lista de productos em base de datos base de datos
    public static ResultSet CargarReporteAuditoria(int operacion, String fechaInicio, String fechaFin) throws SQLException {
        resultado = null;
        ResultSet valorRetorno = null;
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_GENERA_REPORTE_AUDITORIA(?,?,?)}");
            proc.setInt(1, operacion);
            proc.setString(2, fechaInicio);
            proc.setString(3, fechaFin);
            proc.execute();
            resultado = proc.getResultSet();
            while (resultado.next()) {
                valorRetorno = resultado;
                return valorRetorno;
            }
        } catch (SQLException e) {
        }
        return valorRetorno;
    }
    
        //Genera reporte Pedido
    public static void GeneraReportesIventario(int operacionE, String fechaInicioE, String fechaFinE, int estadoInventario) throws JRException, IOException {

        try {
            Map parametros = new HashMap();
            parametros.clear();
            parametros.put("operacion", operacionE);
            parametros.put("fechaInicio", fechaInicioE);
            parametros.put("fechaFin", fechaFinE);
            parametros.put("estadoInventario", estadoInventario);
            String archivo = ADInventario.class.getResource("ADReporteInventario.jrxml").getPath();
            JasperReport report = JasperCompileManager.compileReport(archivo);
            JasperPrint jpPedido = JasperFillManager.fillReport(report, parametros, ADConexionMySQL.ObtenerConexion());
            DateFormat dateFormat = new SimpleDateFormat("yyyyMMddHHmmss");
            Date fechaActual=new java.util.Date();
            String fecha=dateFormat.format(fechaActual);
            JasperExportManager.exportReportToPdfFile(jpPedido, "C:\\INV_SINERCOM\\REPORTE_INVENTARIO\\ReporteInventario_"+fecha+".pdf");
            //JasperViewer.viewReport(jpPedido, false);
            ADConexionMySQL.Desconectar();
        } catch (JRException ex) {
        }
    }
    
    
            //Genera reporte Pedido
    public static void GeneraReportesAuditoria(int operacionE, String fechaInicioE, String fechaFinE) throws JRException, IOException {

        try {
            Map parametros = new HashMap();
            parametros.clear();
            parametros.put("operacion", operacionE);
            parametros.put("fechaInicio", fechaInicioE);
            parametros.put("fechaFin", fechaFinE);
            String archivo = ADInventario.class.getResource("ADReporteAuditoria.jrxml").getPath();
            JasperReport report = JasperCompileManager.compileReport(archivo);
            JasperPrint jpPedido = JasperFillManager.fillReport(report, parametros, ADConexionMySQL.ObtenerConexion());
            DateFormat dateFormat = new SimpleDateFormat("yyyyMMddHHmmss");
            Date fechaActual=new java.util.Date();
            String fecha=dateFormat.format(fechaActual);
            JasperExportManager.exportReportToPdfFile(jpPedido, "C:\\INV_SINERCOM\\REPORTE_AUDITORIA\\ReporteAudtoria_"+fecha+".pdf");
            //JasperViewer.viewReport(jpPedido, false);
            ADConexionMySQL.Desconectar();
        } catch (JRException ex) {
        }
    }
}
