package INV_SINERCOM.AccesoDatos;

import java.sql.*;
import javax.swing.*;
import java.util.*;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.net.URL;
import java.net.URLConnection;

public class ADUsuarios {

    /// <summary>
    /// Aplicación: INV_SINERCOM (INVENTARIO SINERCOM)
    /// Módulo: USUARIOS
    /// Fecha:2014/09/30 
    /// Empresa:SINERCOM
    /// HISTORIA DE CAMBIOS
    /// ----------------------------------------------------------------------
    /// FECHA         USUARIO     DESCRIPCION
    /// 2014/09/30    DRPAREDA    Creacion de Clase para manejo de USUARIOS
    /// ----------------------------------------------------------------------
    /// </summary>
    
    private static ResultSet resultado = null;

    //Verifica datos del usuario a logearse
    public static ArrayList Login(String usuario, String contrasena) {
        ArrayList valorRetorno = new ArrayList();
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_VALIDA_USUARIO(?, ?)}");
            proc.setString(1, usuario);
            proc.setString(2, contrasena);
            proc.execute();
            resultado = proc.getResultSet();
            while (resultado.next()) {
                valorRetorno.add(resultado.getString(1));
                valorRetorno.add(resultado.getString(2));
            }
            ADConexionMySQL.Desconectar();
        } catch (SQLException e) {
        }
        return valorRetorno;
    }

    //Obtiene perfil del usuario logeado
    public static String ObtienePerfilUsuario(String usuario) {
        String valorRetorno = "";
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_VALIDA_PERFIL_USUARIO(?)}");
            proc.setString(1, usuario);
            proc.execute();
            resultado = proc.getResultSet();
            if (resultado.next()) {
                valorRetorno = resultado.getString(1);
            }
            ADConexionMySQL.Desconectar();
        } catch (SQLException e) {
        }
        return valorRetorno;
    }
    
    //Carga empleados de la empresa disponibls en a base de datos
    public static ArrayList CargaEmpleados(int operacion) {
        ArrayList valorRetorno = new ArrayList();
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_CONSULTA_EMPLEADOS_USUARIO(?)}");
            proc.setInt(1, operacion);
            proc.execute();
            resultado = proc.getResultSet();
            while (resultado.next()) {
                valorRetorno.add(resultado.getString(1));
            }
            ADConexionMySQL.Desconectar();
        } catch (SQLException e) {
        }
        return valorRetorno;
    }
    
     //Valida empleados si esta asociados ya a un usuario
    public static int ValidaEmpleadoUsuario(int operacion,int codigoEmpleado, int codigoUsuario) {
        int valorRetorno = 0;
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_VALIDA_EMPLEADO_USUARIO(?,?,?)}");
            proc.setInt(1, operacion);
            proc.setInt(2, codigoEmpleado);
            proc.setInt(3, codigoUsuario);
            proc.execute();
            resultado = proc.getResultSet();
            while (resultado.next()) {
                valorRetorno = resultado.getInt(1);
            }
            ADConexionMySQL.Desconectar();
        } catch (SQLException e) {
        }
        return valorRetorno;
    }

    // Inserta nuevo usuario en base de datos
    public static int RegistraUsuario(String nombreUsuario, String claveUsuario, int indexCombo,int indexEmpleado) {
        int valorRetorno = 0;
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_REGISTRA_USUARIO(?,?,?,?)}");
            proc.setString(1, nombreUsuario);
            proc.setString(2, claveUsuario);
            proc.setInt(3, indexCombo);
            proc.setInt(4, indexEmpleado);
            proc.execute();
            resultado = proc.getResultSet();
            if (resultado.next()) {
                valorRetorno = resultado.getInt(1);
            }
            ADConexionMySQL.Desconectar();
        } catch (SQLException e) {
        }
        return valorRetorno;
    }

    //Carga perfiles de usuarios del sistema disponibls en a base de datos
    public static ArrayList CargaPerfilUsuario() {

        ArrayList valorRetorno = new ArrayList();
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_CONSULTA_PERFIL()}");
            proc.execute();
            resultado = proc.getResultSet();
            while (resultado.next()) {
                valorRetorno.add(resultado.getString("nombre_acceso"));
            }
            ADConexionMySQL.Desconectar();
        } catch (SQLException e) {
        }

        return valorRetorno;
    }

    //Busca usuario en especifico en la base de datos
    public static ArrayList BuscarUsuario(int operacion,String nombreUsuario, int CodigoUsuario) {
        ArrayList valorRetorno = new ArrayList();
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_BUSCAR_USUARIO(?,?,?)}");
            proc.setInt(1, operacion);
            proc.setString(2, nombreUsuario);
            proc.setInt(3, CodigoUsuario);
            proc.execute();
            resultado = proc.getResultSet();
            while (resultado.next()) {
                valorRetorno.add(resultado.getInt("CODIGO"));
                valorRetorno.add(resultado.getString("USUARIO"));
                valorRetorno.add(resultado.getString("CLAVE"));
                valorRetorno.add(resultado.getInt("CODIGO_PERFIL"));
                valorRetorno.add(resultado.getInt("CODIGO_EMPLEADO"));
                valorRetorno.add(resultado.getString("ESTADO"));
            }
            if (valorRetorno.isEmpty()) {
                valorRetorno.add(0);
            }
            ADConexionMySQL.Desconectar();
        } catch (SQLException e) {
        }

        return valorRetorno;
    }

    // Actualiza informacion de Usuario en base de datos
    public static int ActualizarUsuario(int codigoUsuario, String claveUsuario, int indexCombo,int indexEmpleado, String estadoUsuario) {
        int valorRetorno = 0;
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_ACTUALIZAR_USUARIO(?,?,?,?,?)}");
            proc.setInt(1, codigoUsuario);
            proc.setString(2, claveUsuario);
            proc.setInt(3, indexCombo);
            proc.setInt(4, indexEmpleado);
            proc.setString(5, estadoUsuario);
            proc.execute();
            resultado = proc.getResultSet();
            if (resultado.next()) {
                valorRetorno = resultado.getInt(1);
            }
            ADConexionMySQL.Desconectar();
        } catch (SQLException e) {
        }
        return valorRetorno;
    }
    
    //Elimina informacion de Usuario de la base de datos
    public static int EliminarUsuario(int codigoUsuario, int operacion) {
        int valorRetorno = 0;
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_ELIMINAR_USUARIO(?,?)}");
            proc.setInt(1, codigoUsuario);
            proc.setInt(2, operacion);
            proc.execute();
            resultado = proc.getResultSet();
            if (resultado.next()) {
                valorRetorno = resultado.getInt(1);
            }
            ADConexionMySQL.Desconectar();
        } catch (SQLException e) {
        }
        return valorRetorno;
    }
    
         //Valida empleados si esta asociados ya a un usuario
    public static int CambiaClaveUsuario(int operacion,String usuario, String clave) {
        int valorRetorno = -1;
        try {
            CallableStatement proc = ADConexionMySQL.ObtenerConexion().prepareCall("{call PRO_RESETEA_USUARIO(?,?,?)}");
            proc.setInt(1, operacion);
            proc.setString(2, usuario);
            proc.setString(3, clave);
            proc.execute();
            resultado = proc.getResultSet();
            while (resultado.next()) {
                valorRetorno = resultado.getInt(1);
            }
            ADConexionMySQL.Desconectar();
        } catch (SQLException e) {
        }
        return valorRetorno;
    }
}
